proto

package
v0.26.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 28, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	Connector_Schema_FullMethodName           = "/wick.connector.v1.Connector/Schema"
	Connector_Execute_FullMethodName          = "/wick.connector.v1.Connector/Execute"
	Connector_ExecuteStream_FullMethodName    = "/wick.connector.v1.Connector/ExecuteStream"
	Connector_CheckPermissions_FullMethodName = "/wick.connector.v1.Connector/CheckPermissions"
	Connector_ResolveIdentity_FullMethodName  = "/wick.connector.v1.Connector/ResolveIdentity"
	Connector_Health_FullMethodName           = "/wick.connector.v1.Connector/Health"
)

Variables

var Connector_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "wick.connector.v1.Connector",
	HandlerType: (*ConnectorServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Schema",
			Handler:    _Connector_Schema_Handler,
		},
		{
			MethodName: "Execute",
			Handler:    _Connector_Execute_Handler,
		},
		{
			MethodName: "CheckPermissions",
			Handler:    _Connector_CheckPermissions_Handler,
		},
		{
			MethodName: "ResolveIdentity",
			Handler:    _Connector_ResolveIdentity_Handler,
		},
		{
			MethodName: "Health",
			Handler:    _Connector_Health_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "ExecuteStream",
			Handler:       _Connector_ExecuteStream_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "connector.proto",
}

Connector_ServiceDesc is the grpc.ServiceDesc for Connector service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_connector_proto protoreflect.FileDescriptor

Functions

func RegisterConnectorServer

func RegisterConnectorServer(s grpc.ServiceRegistrar, srv ConnectorServer)

Types

type Chunk

type Chunk struct {
	Data     []byte `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	Eof      bool   `protobuf:"varint,2,opt,name=eof,proto3" json:"eof,omitempty"`
	Error    *Error `protobuf:"bytes,3,opt,name=error,proto3" json:"error,omitempty"`
	Progress int32  `protobuf:"varint,4,opt,name=progress,proto3" json:"progress,omitempty"`
	Total    int32  `protobuf:"varint,5,opt,name=total,proto3" json:"total,omitempty"`
	Message  string `protobuf:"bytes,6,opt,name=message,proto3" json:"message,omitempty"`
	// contains filtered or unexported fields
}

func (*Chunk) Descriptor deprecated

func (*Chunk) Descriptor() ([]byte, []int)

Deprecated: Use Chunk.ProtoReflect.Descriptor instead.

func (*Chunk) GetData

func (x *Chunk) GetData() []byte

func (*Chunk) GetEof

func (x *Chunk) GetEof() bool

func (*Chunk) GetError

func (x *Chunk) GetError() *Error

func (*Chunk) GetMessage

func (x *Chunk) GetMessage() string

func (*Chunk) GetProgress

func (x *Chunk) GetProgress() int32

func (*Chunk) GetTotal

func (x *Chunk) GetTotal() int32

func (*Chunk) ProtoMessage

func (*Chunk) ProtoMessage()

func (*Chunk) ProtoReflect

func (x *Chunk) ProtoReflect() protoreflect.Message

func (*Chunk) Reset

func (x *Chunk) Reset()

func (*Chunk) String

func (x *Chunk) String() string

type ConnectorClient

type ConnectorClient interface {
	Schema(ctx context.Context, in *SchemaRequest, opts ...grpc.CallOption) (*SchemaResponse, error)
	Execute(ctx context.Context, in *ExecuteRequest, opts ...grpc.CallOption) (*ExecuteResponse, error)
	ExecuteStream(ctx context.Context, in *ExecuteRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[Chunk], error)
	CheckPermissions(ctx context.Context, in *PermsRequest, opts ...grpc.CallOption) (*PermsResponse, error)
	ResolveIdentity(ctx context.Context, in *IdentityRequest, opts ...grpc.CallOption) (*IdentityResponse, error)
	Health(ctx context.Context, in *HealthRequest, opts ...grpc.CallOption) (*HealthResponse, error)
}

ConnectorClient is the client API for Connector service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewConnectorClient

func NewConnectorClient(cc grpc.ClientConnInterface) ConnectorClient

type ConnectorServer

type ConnectorServer interface {
	Schema(context.Context, *SchemaRequest) (*SchemaResponse, error)
	Execute(context.Context, *ExecuteRequest) (*ExecuteResponse, error)
	ExecuteStream(*ExecuteRequest, grpc.ServerStreamingServer[Chunk]) error
	CheckPermissions(context.Context, *PermsRequest) (*PermsResponse, error)
	ResolveIdentity(context.Context, *IdentityRequest) (*IdentityResponse, error)
	Health(context.Context, *HealthRequest) (*HealthResponse, error)
	// contains filtered or unexported methods
}

ConnectorServer is the server API for Connector service. All implementations must embed UnimplementedConnectorServer for forward compatibility.

type Connector_ExecuteStreamClient

type Connector_ExecuteStreamClient = grpc.ServerStreamingClient[Chunk]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type Connector_ExecuteStreamServer

type Connector_ExecuteStreamServer = grpc.ServerStreamingServer[Chunk]

This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.

type Error

type Error struct {
	Code    string `protobuf:"bytes,1,opt,name=code,proto3" json:"code,omitempty"`
	Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	// contains filtered or unexported fields
}

func (*Error) Descriptor deprecated

func (*Error) Descriptor() ([]byte, []int)

Deprecated: Use Error.ProtoReflect.Descriptor instead.

func (*Error) GetCode

func (x *Error) GetCode() string

func (*Error) GetMessage

func (x *Error) GetMessage() string

func (*Error) ProtoMessage

func (*Error) ProtoMessage()

func (*Error) ProtoReflect

func (x *Error) ProtoReflect() protoreflect.Message

func (*Error) Reset

func (x *Error) Reset()

func (*Error) String

func (x *Error) String() string

type ExecuteRequest

type ExecuteRequest struct {
	Operation string            `protobuf:"bytes,1,opt,name=operation,proto3" json:"operation,omitempty"`
	ArgsJson  []byte            `protobuf:"bytes,2,opt,name=args_json,json=argsJson,proto3" json:"args_json,omitempty"`
	Creds     map[string]string `` /* 137-byte string literal not displayed */
	RequestId string            `protobuf:"bytes,4,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
	SessionId string            `protobuf:"bytes,5,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
	// contains filtered or unexported fields
}

func (*ExecuteRequest) Descriptor deprecated

func (*ExecuteRequest) Descriptor() ([]byte, []int)

Deprecated: Use ExecuteRequest.ProtoReflect.Descriptor instead.

func (*ExecuteRequest) GetArgsJson

func (x *ExecuteRequest) GetArgsJson() []byte

func (*ExecuteRequest) GetCreds

func (x *ExecuteRequest) GetCreds() map[string]string

func (*ExecuteRequest) GetOperation

func (x *ExecuteRequest) GetOperation() string

func (*ExecuteRequest) GetRequestId

func (x *ExecuteRequest) GetRequestId() string

func (*ExecuteRequest) GetSessionId

func (x *ExecuteRequest) GetSessionId() string

func (*ExecuteRequest) ProtoMessage

func (*ExecuteRequest) ProtoMessage()

func (*ExecuteRequest) ProtoReflect

func (x *ExecuteRequest) ProtoReflect() protoreflect.Message

func (*ExecuteRequest) Reset

func (x *ExecuteRequest) Reset()

func (*ExecuteRequest) String

func (x *ExecuteRequest) String() string

type ExecuteResponse

type ExecuteResponse struct {
	ResultJson []byte            `protobuf:"bytes,1,opt,name=result_json,json=resultJson,proto3" json:"result_json,omitempty"`
	Error      *Error            `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
	Meta       map[string]string `` /* 135-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*ExecuteResponse) Descriptor deprecated

func (*ExecuteResponse) Descriptor() ([]byte, []int)

Deprecated: Use ExecuteResponse.ProtoReflect.Descriptor instead.

func (*ExecuteResponse) GetError

func (x *ExecuteResponse) GetError() *Error

func (*ExecuteResponse) GetMeta

func (x *ExecuteResponse) GetMeta() map[string]string

func (*ExecuteResponse) GetResultJson

func (x *ExecuteResponse) GetResultJson() []byte

func (*ExecuteResponse) ProtoMessage

func (*ExecuteResponse) ProtoMessage()

func (*ExecuteResponse) ProtoReflect

func (x *ExecuteResponse) ProtoReflect() protoreflect.Message

func (*ExecuteResponse) Reset

func (x *ExecuteResponse) Reset()

func (*ExecuteResponse) String

func (x *ExecuteResponse) String() string

type HealthRequest

type HealthRequest struct {
	// contains filtered or unexported fields
}

func (*HealthRequest) Descriptor deprecated

func (*HealthRequest) Descriptor() ([]byte, []int)

Deprecated: Use HealthRequest.ProtoReflect.Descriptor instead.

func (*HealthRequest) ProtoMessage

func (*HealthRequest) ProtoMessage()

func (*HealthRequest) ProtoReflect

func (x *HealthRequest) ProtoReflect() protoreflect.Message

func (*HealthRequest) Reset

func (x *HealthRequest) Reset()

func (*HealthRequest) String

func (x *HealthRequest) String() string

type HealthResponse

type HealthResponse struct {
	Healthy bool   `protobuf:"varint,1,opt,name=healthy,proto3" json:"healthy,omitempty"`
	Detail  string `protobuf:"bytes,2,opt,name=detail,proto3" json:"detail,omitempty"`
	// contains filtered or unexported fields
}

func (*HealthResponse) Descriptor deprecated

func (*HealthResponse) Descriptor() ([]byte, []int)

Deprecated: Use HealthResponse.ProtoReflect.Descriptor instead.

func (*HealthResponse) GetDetail

func (x *HealthResponse) GetDetail() string

func (*HealthResponse) GetHealthy

func (x *HealthResponse) GetHealthy() bool

func (*HealthResponse) ProtoMessage

func (*HealthResponse) ProtoMessage()

func (*HealthResponse) ProtoReflect

func (x *HealthResponse) ProtoReflect() protoreflect.Message

func (*HealthResponse) Reset

func (x *HealthResponse) Reset()

func (*HealthResponse) String

func (x *HealthResponse) String() string

type IdentityRequest

type IdentityRequest struct {
	AccessToken string `protobuf:"bytes,1,opt,name=access_token,json=accessToken,proto3" json:"access_token,omitempty"`
	// contains filtered or unexported fields
}

func (*IdentityRequest) Descriptor deprecated

func (*IdentityRequest) Descriptor() ([]byte, []int)

Deprecated: Use IdentityRequest.ProtoReflect.Descriptor instead.

func (*IdentityRequest) GetAccessToken

func (x *IdentityRequest) GetAccessToken() string

func (*IdentityRequest) ProtoMessage

func (*IdentityRequest) ProtoMessage()

func (*IdentityRequest) ProtoReflect

func (x *IdentityRequest) ProtoReflect() protoreflect.Message

func (*IdentityRequest) Reset

func (x *IdentityRequest) Reset()

func (*IdentityRequest) String

func (x *IdentityRequest) String() string

type IdentityResponse

type IdentityResponse struct {
	UserId      string `protobuf:"bytes,1,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`
	DisplayName string `protobuf:"bytes,2,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	Error       *Error `protobuf:"bytes,3,opt,name=error,proto3" json:"error,omitempty"`
	// contains filtered or unexported fields
}

func (*IdentityResponse) Descriptor deprecated

func (*IdentityResponse) Descriptor() ([]byte, []int)

Deprecated: Use IdentityResponse.ProtoReflect.Descriptor instead.

func (*IdentityResponse) GetDisplayName

func (x *IdentityResponse) GetDisplayName() string

func (*IdentityResponse) GetError

func (x *IdentityResponse) GetError() *Error

func (*IdentityResponse) GetUserId

func (x *IdentityResponse) GetUserId() string

func (*IdentityResponse) ProtoMessage

func (*IdentityResponse) ProtoMessage()

func (*IdentityResponse) ProtoReflect

func (x *IdentityResponse) ProtoReflect() protoreflect.Message

func (*IdentityResponse) Reset

func (x *IdentityResponse) Reset()

func (*IdentityResponse) String

func (x *IdentityResponse) String() string

type OpHealth

type OpHealth struct {
	Key    string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	Ok     bool   `protobuf:"varint,2,opt,name=ok,proto3" json:"ok,omitempty"`
	Reason string `protobuf:"bytes,3,opt,name=reason,proto3" json:"reason,omitempty"`
	// contains filtered or unexported fields
}

func (*OpHealth) Descriptor deprecated

func (*OpHealth) Descriptor() ([]byte, []int)

Deprecated: Use OpHealth.ProtoReflect.Descriptor instead.

func (*OpHealth) GetKey

func (x *OpHealth) GetKey() string

func (*OpHealth) GetOk

func (x *OpHealth) GetOk() bool

func (*OpHealth) GetReason

func (x *OpHealth) GetReason() string

func (*OpHealth) ProtoMessage

func (*OpHealth) ProtoMessage()

func (*OpHealth) ProtoReflect

func (x *OpHealth) ProtoReflect() protoreflect.Message

func (*OpHealth) Reset

func (x *OpHealth) Reset()

func (*OpHealth) String

func (x *OpHealth) String() string

type PermsRequest

type PermsRequest struct {
	Creds map[string]string `` /* 137-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*PermsRequest) Descriptor deprecated

func (*PermsRequest) Descriptor() ([]byte, []int)

Deprecated: Use PermsRequest.ProtoReflect.Descriptor instead.

func (*PermsRequest) GetCreds

func (x *PermsRequest) GetCreds() map[string]string

func (*PermsRequest) ProtoMessage

func (*PermsRequest) ProtoMessage()

func (*PermsRequest) ProtoReflect

func (x *PermsRequest) ProtoReflect() protoreflect.Message

func (*PermsRequest) Reset

func (x *PermsRequest) Reset()

func (*PermsRequest) String

func (x *PermsRequest) String() string

type PermsResponse

type PermsResponse struct {
	Ops   []*OpHealth `protobuf:"bytes,1,rep,name=ops,proto3" json:"ops,omitempty"`
	Error *Error      `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
	// contains filtered or unexported fields
}

func (*PermsResponse) Descriptor deprecated

func (*PermsResponse) Descriptor() ([]byte, []int)

Deprecated: Use PermsResponse.ProtoReflect.Descriptor instead.

func (*PermsResponse) GetError

func (x *PermsResponse) GetError() *Error

func (*PermsResponse) GetOps

func (x *PermsResponse) GetOps() []*OpHealth

func (*PermsResponse) ProtoMessage

func (*PermsResponse) ProtoMessage()

func (*PermsResponse) ProtoReflect

func (x *PermsResponse) ProtoReflect() protoreflect.Message

func (*PermsResponse) Reset

func (x *PermsResponse) Reset()

func (*PermsResponse) String

func (x *PermsResponse) String() string

type SchemaRequest

type SchemaRequest struct {
	// contains filtered or unexported fields
}

func (*SchemaRequest) Descriptor deprecated

func (*SchemaRequest) Descriptor() ([]byte, []int)

Deprecated: Use SchemaRequest.ProtoReflect.Descriptor instead.

func (*SchemaRequest) ProtoMessage

func (*SchemaRequest) ProtoMessage()

func (*SchemaRequest) ProtoReflect

func (x *SchemaRequest) ProtoReflect() protoreflect.Message

func (*SchemaRequest) Reset

func (x *SchemaRequest) Reset()

func (*SchemaRequest) String

func (x *SchemaRequest) String() string

type SchemaResponse

type SchemaResponse struct {
	ManifestJson []byte `protobuf:"bytes,1,opt,name=manifest_json,json=manifestJson,proto3" json:"manifest_json,omitempty"`
	// contains filtered or unexported fields
}

func (*SchemaResponse) Descriptor deprecated

func (*SchemaResponse) Descriptor() ([]byte, []int)

Deprecated: Use SchemaResponse.ProtoReflect.Descriptor instead.

func (*SchemaResponse) GetManifestJson

func (x *SchemaResponse) GetManifestJson() []byte

func (*SchemaResponse) ProtoMessage

func (*SchemaResponse) ProtoMessage()

func (*SchemaResponse) ProtoReflect

func (x *SchemaResponse) ProtoReflect() protoreflect.Message

func (*SchemaResponse) Reset

func (x *SchemaResponse) Reset()

func (*SchemaResponse) String

func (x *SchemaResponse) String() string

type UnimplementedConnectorServer

type UnimplementedConnectorServer struct{}

UnimplementedConnectorServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedConnectorServer) CheckPermissions

func (UnimplementedConnectorServer) Execute

func (UnimplementedConnectorServer) ExecuteStream

func (UnimplementedConnectorServer) Health

func (UnimplementedConnectorServer) ResolveIdentity

func (UnimplementedConnectorServer) Schema

type UnsafeConnectorServer

type UnsafeConnectorServer interface {
	// contains filtered or unexported methods
}

UnsafeConnectorServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ConnectorServer will result in compilation errors.

Jump to